==> core-react-0.8.0.tgz: package/es/Layout/Row/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';


var Row = function Row(props) {
  var _cx;

  var children = props.children,
      className = props.className,
      gutter = props.gutter,
      fluid = props.fluid,
      other = _objectWithoutProperties(props, ["children", "className", "gutter", "fluid"]);

  var classNames = cx("".concat("waui", "-layout__row"), (_cx = {}, _defineProperty(_cx, "".concat("waui", "-layout__row_gutter"), gutter), _defineProperty(_cx, "".concat("waui", "-layout__row_fluid"), fluid), _cx), className);
  return React.createElement("div", _extends({
    className: classNames
  }, other), children);
};

Row.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** Whether to have gutter */
  gutter: PropTypes.bool,

  /** Whether is fluid */
  fluid: PropTypes.bool
};
export default Row;

==> core-react-0.8.2.tgz: package/es/Layout/Row/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';


var Row = function Row(props) {
  var _cx;

  var children = props.children,
      className = props.className,
      gutter = props.gutter,
      fluid = props.fluid,
      other = _objectWithoutProperties(props, ["children", "className", "gutter", "fluid"]);

  var classNames = cx("".concat("waui", "-layout__row"), (_cx = {}, _defineProperty(_cx, "".concat("waui", "-layout__row_gutter"), gutter), _defineProperty(_cx, "".concat("waui", "-layout__row_fluid"), fluid), _cx), className);
  return (/*#__PURE__*/React.createElement("div", _extends({
      className: classNames
    }, other), children)
  );
};

Row.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** Whether to have gutter */
  gutter: PropTypes.bool,

  /** Whether is fluid */
  fluid: PropTypes.bool
};
export default Row;
